@@ -24,12 +24,12 @@
 ##
 ##  Set 'GAP_DIR' to the name of the directory where you have installed  GAP,
 ##  i.e., the directory with the subdirectories  'lib',  'grp',  'doc',  etc.
-##  The default is '/build/gap/src/gap-4.15.0',  which is the root directory if you install
+##  The default is '/build/gap/src/gap',  which is the root directory if you install
 ##  XGAP in the default `pkg' directory.
 ##  If you install XGAP in a private directory you have to change this.
 ##
 if [ "x$GAP_DIR" = "x" ];  then
-GAP_DIR="/build/gap/src/gap-4.15.0"
+GAP_DIR="/build/gap/src/gap"
 fi
 
 
@@ -220,7 +220,7 @@ fi;
 #############################################################################
 ##
 ##
-XGAP=/build/gap/src/gap-4.15.0/pkg/xgap/bin/$XGAP_PRG
+XGAP=/build/gap/src/gap/pkg/xgap/bin/$XGAP_PRG
 GAP=$GAP_DIR/bin/$GAP_PRG
 
 #############################################################################
